@@ -19,11 +19,12 @@ from dap_core import common
 
 class NoActionError:
   action_name = "un-specified"
+
   def __init__(self, action_name = "un-specified"):
     self.action_name = action_name
     return
 
   def run(self):
-    error_message = "Action '" + self.action_name + "' not found"
+    error_message = "No action named '" + self.action_name + "' found."
     common.print_error(error_message)
     return 1, error_message
\ No newline at end of file
